@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 # ReText webpages generator
-# Copyright 2011-2012 Dmitry Shachnev
+# Copyright 2011-2013 Dmitry Shachnev
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,8 @@
 # MA 02110-1301, USA.
 
 import sys
-from ReText.webpages import *
+from ReText import app_name, app_version
+from ReText.webpages import wpUpdate, wpUpdateAll, wpInit, wpUseStyle
 
 def main(argv):
 	if len(argv) > 1:
